# Repetitive Behavior Detected

**WARNING: You have called the same tool `{tool_name}` {count} times consecutively.**

This may indicate:

1. **Search strategy needs adjustment** - Try different keywords or tools

2. **You may already have enough information** - Consider providing an answer

3. **The problem may need to be broken down** - Try splitting into smaller sub-problems

Please adjust your strategy, or if you have enough information, provide the final answer.
